import { Component } from '@angular/core';
import {MatIconModule} from "@angular/material/icon";
import {MatButtonModule} from "@angular/material/button";
import {MatTreeFlatDataSource, MatTreeFlattener, MatTreeModule} from "@angular/material/tree";
import {FlatTreeControl} from "@angular/cdk/tree";


interface TreeNode {
  name: string
  children?: TreeNode[]
}

const TREE_DATA: TreeNode[] = [
  {
    name: "KIT",
    children: [
      {
        name: "WS23",
        children: [
          {
            name: "Computergrafik",
            children: [{name: "Vorlesungen"}, {name: "Globalübungen"}]
          },
          {
            name: "Softwaretechnik II",
            children: [{name: "Vorlesungen"}, {name: "Globalübungen"}]
          },
          {
            name: "Algorithmen II",
            children: [{name: "Vorlesungen"}, {name: "Globalübungen"}]
          }
        ]
      },
      {
        name: "SS24",
        children: [
          {
            name: "Interaktive Computergrafik",
            children: [{name: "Vorlesungen"}, {name: "Globalübungen"}]
          }
        ]
      }
    ]
  }
]

/** Flat node with expandable and level information */
interface ExampleFlatNode {
  expandable: boolean;
  name: string;
  level: number;
}
@Component({
  selector: 'app-taskgroup-overview',
  templateUrl: './taskgroup-overview.component.html',
  styleUrls: ['./taskgroup-overview.component.css']
})
export class TaskgroupOverviewComponent {

  private _transformer = (node: TreeNode, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
    };
  };

  treeControl = new FlatTreeControl<ExampleFlatNode>(
    node => node.level,
    node => node.expandable,
  );

  treeFlattener = new MatTreeFlattener(
    this._transformer,
    node => node.level,
    node => node.expandable,
    node => node.children,
  );

  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);

  constructor() {
    this.dataSource.data = TREE_DATA;
  }

  hasChild = (_: number, node: ExampleFlatNode) => node.expandable;
}
